@@ -77,7 +77,8 @@ void GroupActionsWindow::PopulateContactsTable()
 
             QLabel* lbl = new QLabel(this);
             lbl->setAlignment(Qt::AlignCenter);
-            lbl->setMaximumSize(48, 48);
+            lbl->setMaximumWidth(48);
+            //lbl->setMaximumSize(48, 48);
             if (c->Thumbnail != NULL)
                 lbl->setPixmap(QPixmap::fromImage(*c->Thumbnail).scaled(48, 48, Qt::KeepAspectRatio));
             else{
@@ -150,33 +151,16 @@ void GroupActionsWindow::SendSlot()
                                          .arg(toSend.count())
                                          .arg(m_Group->Name)) == QMessageBox::Yes){
 #ifdef Q_WS_MAEMO_5
-
-            QMessage message;
-            QMessageService service;
-
-            message.setType(QMessage::Sms);
-
-            QMessageAddressList receiver;
-            foreach(QString n, toSend){
-                QMessageAddress adr(QMessageAddress::Phone, n);
-                receiver.append(adr);
-            }
-            message.setTo(receiver);
-
             QString strTo;
-            foreach (QMessageAddress a, receiver){
+            foreach (QString n, toSend){
                 if (!strTo.isEmpty())
                     strTo.append(", ");
-                strTo.append(a.addressee());
+                strTo.append(n);
             }
 
             QUrl smsUrl((QString("sms:%1").arg(strTo)));
-            smsUrl.addQueryItem("body",message.textContent());
+            smsUrl.addQueryItem("body", "");
             hildon_uri_open(smsUrl.toString().toStdString().c_str(),NULL,NULL);
-
-            /*if (!service.compose(message)){
-                CommonStatic::ErrorMessage(this, tr("Failed to compose SMS"));
-            }*/
 #endif
         }
     }
